"""
Australian Renewable Energy API

    - REC Registry (https://www.rec-registry.gov.au/)

"""

import requests
import pandas as pd
from pandas.io.json import json_normalize

def __call_api(endpoint):
    return requests.get(f"https://www.rec-registry.gov.au/rec-registry/app/api/public-register/certificate-actions?date={endpoint}").json()


def _basic_rec_call(recDay):
    result = __call_api(recDay)

    df = pd.io.json.json_normalize(result,["result"],record_prefix=None)
    df.reset_index(level=0, inplace=True)
    rangeDF = df["certificateRanges"].apply(pd.Series)
    mergedDF = pd.concat([df.drop(['certificateRanges'], axis=1), rangeDF], axis=1)

    return mergedDF


def recDay(recDay):
    return _basic_rec_call(recDay = recDay)









class commonData:
    dictEiaReports = dict ([
        #region COAL
            #region Production
        ('worldCoalProduction','INTL.4411-1-WORL-QBTU.A'),
        ('africaCoalProduction','INTL.4411-1-AFRC-QBTU.A'),
        ('australiaCoalProduction','INTL.4411-1-AUS-QBTU.A'),
        ('chinaCoalProduction', 'INTL.4411-1-CHN-QBTU.A'),
        ('asiaCoalProduction','INTL.4411-1-ASOC-QBTU.A'),
        ('northAmericaCoalProduction','INTL.4411-1-NOAM-QBTU.A'),
        ('europeCoalProduction', 'INTL.4411-1-EURO-QBTU.A'),

            #endregion Production
            # region Consumption
         ('worldCoalConsumption', 'INTL.4411-2-WORL-QBTU.A'),
         ('africaCoalConsumption', 'INTL.4411-2-AFRC-QBTU.A'),
         ('australiaCoalConsumption', 'INTL.4411-2-AUS-QBTU.A'),
         ('chinaCoalConsumption', 'INTL.4411-2-CHN-QBTU.A'),
         ('asiaCoalConsumption', 'INTL.4411-2-ASOC-QBTU.A'),
         ('northAmericaCoalConsumption', 'INTL.4411-2-NOAM-QBTU.A'),
         ('europeCoalConsumption', 'INTL.4411-2-EURO-QBTU.A'),
         ('southAmericaCoalConsumption', 'INTL.4411-2-CSAM-QBTU.A'),
            # endregion Consumption
        #endregion COAL

        # region NG
        # region Production
        ('worldNGProduction', 'INTL.4413-1-WORL-QBTU.A'),
        ('africaNGProduction', 'INTL.4413-1-AFRC-QBTU.A'),
        ('australiaNGProduction', 'INTL.4413-1-AUS-QBTU.A'),
        ('chinaNGProduction', 'INTL.4413-1-CHN-QBTU.A'),
        ('asiaNGProduction', 'INTL.4413-1-ASOC-QBTU.A'),
        ('northAmericaNGProduction', 'INTL.4413-1-NOAM-QBTU.A'),
        ('europeNGProduction', 'INTL.4413-1-EURO-QBTU.A'),

        # endregion Production
        # region Consumption
        ('worldNGConsumption', 'INTL.4413-2-WORL-QBTU.A'),
        ('africaNGConsumption', 'INTL.4413-2-AFRC-QBTU.A'),
        ('australiaNGConsumption', 'INTL.4413-2-AUS-QBTU.A'),
        ('chinaNGConsumption', 'INTL.4413-2-CHN-QBTU.A'),
        ('asiaNGConsumption', 'INTL.4413-2-ASOC-QBTU.A'),
        ('northAmericaNGConsumption', 'INTL.4413-2-NOAM-QBTU.A'),
        ('europeNGConsumption', 'INTL.4413-2-EURO-QBTU.A'),
        ('southAmericaNGConsumption', 'INTL.4413-2-CSAM-QBTU.A'),
        # endregion Consumption

        # region Price
        ('henryHubNGSpotPriceDaily', 'NG.RNGWHHD.D'),
        # endregion Price
        # endregion NG

        # region CRUDE
        # region Price
        ('wtiCushingSpotPriceDaily', 'PET.RWTC.D'),
        # endregion Price
        # endregion CRUDE

    ])